@@ -21,10 +21,10 @@ import subprocess
 import typing
 from abc import ABC
 from abc import abstractmethod
+from io import IOBase
 from platform import system
 from subprocess import PIPE
 from time import sleep
-from typing import TextIO
 from urllib import request
 from urllib.error import URLError
 
@@ -48,7 +48,7 @@ class Service(ABC):
 
     def __init__(
         self,
-        executable: str = None,
+        executable_path: str = None,
         port: int = 0,
         log_output: SubprocessStdAlias = None,
         env: typing.Optional[typing.Mapping[typing.Any, typing.Any]] = None,
@@ -56,14 +56,14 @@ class Service(ABC):
     ) -> None:
         if isinstance(log_output, str):
             self.log_output = open(log_output, "a+", encoding="utf-8")
-        elif log_output is subprocess.STDOUT:
+        elif log_output == subprocess.STDOUT:
             self.log_output = None
-        elif log_output is None or log_output is subprocess.DEVNULL:
-            self.log_output = open(os.devnull, "wb")
+        elif log_output is None or log_output == subprocess.DEVNULL:
+            self.log_output = subprocess.DEVNULL
         else:
             self.log_output = log_output
 
-        self._path = executable
+        self._path = executable_path
         self.port = port or utils.free_port()
         # Default value for every python subprocess: subprocess.Popen(..., creationflags=0)
         self.popen_kw = kwargs.pop("popen_kw", {})
@@ -135,8 +135,8 @@ class Service(ABC):
     def stop(self) -> None:
         """Stops the service."""
 
-        if self.log_output != PIPE:
-            if isinstance(self.log_output, TextIO):
+        if self.log_output not in {PIPE, subprocess.DEVNULL}:
+            if isinstance(self.log_output, IOBase):
                 self.log_output.close()
             elif isinstance(self.log_output, int):
                 os.close(self.log_output)
@@ -157,7 +157,11 @@ class Service(ABC):
         silently ignores errors here.
         """
         try:
-            stdin, stdout, stderr = self.process.stdin, self.process.stdout, self.process.stderr
+            stdin, stdout, stderr = (
+                self.process.stdin,
+                self.process.stdout,
+                self.process.stderr,
+            )
             for stream in stdin, stdout, stderr:
                 try:
                     stream.close()  # type: ignore
@@ -212,7 +216,13 @@ class Service(ABC):
                 startupinfo=start_info,
                 **self.popen_kw,
             )
-            logger.debug(f"Started executable: `{self._path}` in a child process with pid: {self.process.pid}")
+            logger.debug(
+                "Started executable: `%s` in a child process with pid: %s using %s to output %s",
+                self._path,
+                self.process.pid,
+                self.creation_flags,
+                self.log_output,
+            )
         except TypeError:
             raise
         except OSError as err:
